/********** DEPENDENCIES **********/

#include <libgccvb.h>
#include "font.h"


/********** DEFINES **********/

#define false 	0
#define true 	1

#define null 	(void *)0x00000000


/********** GLOBALS **********/

u16 pvb_lastPressedButtons = 0;
u8 pvb_language = 0;

#include "text.h"


/********** FUNCTIONS **********/

void pvb_timerHandle() 
{
	//disable interrupts
	timer_int(0);
	VIP_REGS[INTCLR] = VIP_REGS[INTPND];
	//disable timer
	timer_enable(0);
	
	//clear timer state
	timer_clearstat();
	
	//enable timer
	timer_enable(1);
	//enable interrupts
	timer_int(1);
	
	set_intlevel(0);
}

void pvb_setupTimer()
{
	//setup  timer interrupts
	//pvb_timerHandle(): function that gets called when the interrupt fires (i.e. when the timer reaches 0)
	tim_vector = (u32)(pvb_timerHandle); 
	VIP_REGS[INTCLR] = VIP_REGS[INTPND];
	VIP_REGS[INTENB] = 0x0000; //this is only for enabling\disabling different kinds of vpu and error ints
	set_intlevel(0);
	INT_ENABLE;

	//setup timer
	timer_freq(TIMER_100US);
	timer_set(TIME_MS(50)); //timer will get fired every 50ms
	timer_clearstat();
	timer_int(1);
	timer_enable(1);
}

void pvb_initSystem()
{
	//timer interrupts setup
	pvb_setupTimer();
	
	//column table setup
    //vbSetColTable();
	
    //display setup
    vbDisplayOn();
	
	//load font
	copymem((void*)(CharSeg3+0x1000), (void*)PVB_FONT, 256*16);
}

u8 pvb_buttonsPressed(u16 buttons, u8 forceRelease)
{
	if(!(vbReadPad()&buttons)) pvb_lastPressedButtons = 0;

	if( (vbReadPad()&buttons) && 
		((!forceRelease) || (pvb_lastPressedButtons != vbReadPad()))) 
	{
		pvb_lastPressedButtons = vbReadPad();
		return true;
	}
	else
	{
		return false;
	}
}

void pvb_print(u8 bgmap, u16 x, u16 y, u8 *t_string)
{
	// Font consists of the last 256 chars (1792-2047)
	u16 i=0,pos=0,col=x;

	while(t_string[i])
	{
		pos = (y << 6) + x;

		switch(t_string[i])
		{
			case 9:
				// Tab
				x = (x << 2 + 1) >> 2;
				break;
			case 10:
				// Carriage Return
				y++;
				x = col;
				break;
			case 13:
				x = col;
				break;
			default:
				BGMM[(0x1000 * bgmap) + pos] = (u8)t_string[i] + 0x700;
				if (x++ > 63)
				{
					x = col;
					y++;
				}
				break;
		}
		i++;
	}
}
/*
char* pvb_getString(u8 langString[])
{
	return LANG_PRECAUTION[pvb_language];
}
*/


/********** INCLUDES **********/

#include "adjustmentScreen/adjustmentScreen.h"
#include "precautionScreen/precautionScreen.h"